=============
API Reference
=============

This page gives an collection of all public classes and functions that modifies and configures files and Jacquard attributes

jacquard.py
-----------

.. automodule:: wsp_jacquard.jacquard
   :members:

api.py
------

.. automodule:: wsp_jacquard.api
    :members:

exceptions.py
-------------

.. automodule:: wsp_jacquard.exceptions
    :members:
